/*
  pedometer - a tools to retreive data and manage settings from Crivit Z31192 pedometer

  Copyright (c) 2014, Laurent Mazet <mazet@softndesign.org>
*/

#ifndef __PEDOMETER_H__
#define __PEDOMETER_H__

/* system type */

typedef enum {
    system_undef_e = 0,
    system_metric_e = 1,
    system_imperial_e = 2,
    system_unknown_e = 3
} system_t;

/* parameter structure type */

typedef struct {
    int gait; /* in meter or feet */
    system_t system; /* 1 for metric, 0 for imperial */
    int target; /* in step */
    int weight; /* in kg or pound */
} parameter_t;

/* data type */

typedef struct {
    int calories;
    char date[12];
    int distance;
    int steps;
    int walking_time;
} data_t;

/* configuration structure type */
typedef struct {
    system_t system;
} config_t;

/* verbose macros */

#ifndef __PEDOMETER_C__
extern int verbose;
#endif /* __PEDOMETER_C__ */

#define ERROR 0
#define WARNING 1
#define DEBUG 2

#define VERBOSE(level, statement...)\
    do {                                                         \
        if (level <= verbose) {                                  \
            printf ("\033[1;%dm", (level == ERROR) ? 31 :        \
                                  (level == WARNING) ? 33 : 34); \
            statement;                                           \
            printf ("\033[0;0m");                                \
        }                                                        \
    } while(0)

/* Divide and round */

#define DIVROUND(x, y) ((x * y + 5000) / 10000)

int convert_gait (system_t old_system, system_t new_system, int gait);

int convert_weight (system_t old_system, system_t new_system, int weight);

#endif /* __PEDOMETER_H__ */
